from signxml import XMLVerifier, exceptions
from lxml import etree

from django.conf import settings
from django.contrib.auth import authenticate, login


class WSFed(object):
    """ WS-Fed sign-in protocol """

    url = ""
    signin = ""
    signout = ""
    wtrealm = ""

    def __init__(self):
        """ """
        config = getattr(settings, "ADFS_WSFED_CONFIG", {})
        self.url = config.get("url", "")
        self.signin = config.get("signin", "wsignin1.0")
        self.signout = config.get("signout", "wsignout1.0")
        self.wtrealm = config.get("wtrealm", "")

    def get_signin_url(self):
        """ """
        return "%s?wa=%s&wtrealm=%s" % (self.url, self.signin, self.wtrealm)

    def get_signout_url(self):
        """ """
        return "%s?wa=%s" % (self.url, self.signout)


adfs_wsfed = WSFed()


class WSFedAuthentication(object):

    request = ""
    response = ""

    def __init__(self, request, response):
        """ """
        self.request = request
        self.response = response

    def authenticate(self):
        """ """
        verified_data = self.verify_response()

        # Authentication succeeded
        if verified_data is not None:
            user_info = self.extract_values(verified_data)
            user = authenticate(user_info=user_info)
            login(self.request, user)
            return True
        return False

    def verify_response(self):
        """ """
        if not self.response:
            return None

        config = getattr(settings, 'ADFS_WSFED_CONFIG', {})
        certificate = config.get('cert', '')

        cert = open(certificate).read()
        xml = etree.XML(self.response)
        try:
            verified_data = XMLVerifier().verify(xml, require_x509=False,
                                                 x509_cert=cert,
                                                 id_attribute="AssertionID")
        except exceptions.InvalidSignature, exceptions.InvalidInput:
            # verification fail
            return None
        # verification success return VerifyResult obj (XML)
        return verified_data.signed_xml

    def extract_values(self, xml):
        """ extract values from XML result """
        user_info = {}
        config = getattr(settings, 'ADFS_WSFED_CONFIG', {})
        claims = config.get('claim_mapping', {})
        xpath = './/{urn:oasis:names:tc:SAML:1.0:assertion}Attribute'

        attributes = xml.findall(xpath)
        for attr in attributes:
            key = attr.get('AttributeName', 'noattr')
            key = claims.get(key, key)
            user_info[key] = attr.getchildren()[0].text
        return user_info
