import os

from evote.settings import *  # noqa


DEBUG = False
TEMPLATE_DEBUG = True
COMPRESS_OFFLINE = True


ALLOWED_HOSTS = ['evote.dev.eurotux.com']

SECRET_KEY = os.environ.get('SECRET_KEY')

MIDDLEWARE += (  # noqa
    'django.middleware.gzip.GZipMiddleware',
)

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': "evote",
        'USER': os.environ.get('MYSQL_USER'),
        'PASSWORD': os.environ.get('MYSQL_PASSWORD'),
        'HOST': os.environ.get('MYSQL_HOST'),
        'PORT': '',
        'OPTIONS': {
            'init_command': 'SET storage_engine=INNODB'
        },
    }
}

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": "redis://evote-redis-dev:6379/0",
        "KEY_PREFIX": "evote",
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}


# Define the Queue Settings

BROKER_URL = os.environ.get('BROKER_URL')


# sorl thumbnail settings

THUMBNAIL_REDIS_URL = "redis://evote-redis-dev:6379/0"
THUMBNAIL_KVSTORE = "sorl.thumbnail.kvstores.redis_kvstore.KVStore"
THUMBNAIL_DUMMY = True


# Logging

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'class': 'django.utils.log.AdminEmailHandler',
            'include_html': True
        }
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },
    },
}

# Django Site identification
SITE_ID = 4

# WS UM Members
MEMBERS_SERVICE_CONFIG = {
    'debug': True,
    'url': '',
    'login': '',
    'password': ''
}

# WS UM SMS Notifications
SMS_SERVICE_CONFIG = {
    'debug': True,
    'url': '',
    'login': '',
    'password': ''
}


# evote services endpoints

EVOTE_SERVICES_ENDPOINTS = {
    'anonymizer': 'https://evote-as.dev.eurotux.com/api/v1/',
    'counter': 'https://evote-cs.dev.eurotux.com/api/v1/'
}
# TODO: Propagate to the router class
EVOTE_ANONYMIZER_ENDPOINT = EVOTE_SERVICES_ENDPOINTS['anonymizer']
EVOTE_ANONYMIZER_INSERT_VOTE = EVOTE_ANONYMIZER_ENDPOINT + 'anonymizevote/'
