import os

from evote.settings import *  # noqa
from django.core.urlresolvers import reverse_lazy

import mimetypes

mimetypes.add_type("image/svg+xml", ".svg", True)
mimetypes.add_type("image/svg+xml", ".svgz", True)


DEBUG = True
TEMPLATE_DEBUG = True
THUMBNAIL_DEBUG = True


# debug toolbar settings
def show_toolbar(request):
    return True


DEBUG_TOOLBAR_PATCH_SETTINGS = False
INSTALLED_APPS += (  # noqa
    'debug_toolbar',
)
MIDDLEWARE += [  # noqa
    'debug_toolbar.middleware.DebugToolbarMiddleware',
]
DEBUG_TOOLBAR_CONFIG = {
    "SHOW_TOOLBAR_CALLBACK": show_toolbar,
}


# database settings

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': os.environ.get('MYSQL_DATABASE'),
        'USER': os.environ.get('MYSQL_USER'),
        'PASSWORD': os.environ.get('MYSQL_PASSWORD'),
        'HOST': 'db',
        'PORT': '3306'
    }
}


# caching settings

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": os.environ.get('REDIS_PORT'),
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}

LOGIN_URL = reverse_lazy("voters:login")
LOGOUT_URL = reverse_lazy("voters:logout")

# celery settings

BROKER_URL = 'amqp://{}:{}@rabbitmq//'.format(
    os.environ.get('RABBITMQ_DEFAULT_USER'),
    os.environ.get('RABBITMQ_DEFAULT_PASS'))


# sorl thumbnail settings

THUMBNAIL_REDIS_URL = os.environ.get('REDIS_PORT')
THUMBNAIL_KVSTORE = "sorl.thumbnail.kvstores.redis_kvstore.KVStore"
THUMBNAIL_DUMMY = True
THUMBNAIL_DEBUG = True

# Celery email backend
CELERY_EMAIL_BACKEND = 'django.core.mail.backends.console.EmailBackend'

# Email settings
DEFAULT_FROM_EMAIL = 'dev@eurotux.com'
EVOTE_MAILING_SUBJECT_DEFAULT = 'Evote'

# evote services endpoints
EVOTE_SERVICES_ENDPOINTS = {
    'anonymizer': 'http://anonymizerservice/api/v1/',
    'counter': 'http://counterservice/api/v1/'
}
# TODO: Propagate to the router class
EVOTE_ANONYMIZER_ENDPOINT = 'http://anonymizerservice/api/v1/'
EVOTE_ANONYMIZER_INSERT_VOTE = EVOTE_ANONYMIZER_ENDPOINT + 'anonymizevote/'

# Django Site identification
SITE_ID = 1

# WS UM Members
MEMBERS_SERVICE_CONFIG = {
    'debug': True,
    'url': '',
    'login': '',
    'password': ''
}

# WS UM SMS Notifications
SMS_SERVICE_CONFIG = {
    'debug': True,
    'url': '',
    'login': '',
    'password': ''
}
