import os

from evote.settings import *  # noqa
from django.core.urlresolvers import reverse_lazy


DEBUG = False
TEMPLATE_DEBUG = True
COMPRESS_OFFLINE = True


ALLOWED_HOSTS = ['evote.uminho-dev.local']

SECRET_KEY = os.environ.get('SECRET_KEY')

MIDDLEWARE += (  # noqa
    'django.middleware.gzip.GZipMiddleware',
)

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': os.environ.get('MYSQL_DATABASE'),
        'USER': os.environ.get('MYSQL_USER'),
        'PASSWORD': os.environ.get('MYSQL_PASSWORD'),
        'HOST': os.environ.get('MYSQL_HOST'),
        'PORT': '',
        'OPTIONS': {
            'init_command': 'SET storage_engine=INNODB'
        },
    }
}

CACHES = {
    "default": {
        "BACKEND": "django_redis.cache.RedisCache",
        "LOCATION": "redis://127.0.0.1:6379/0",
        "KEY_PREFIX": "evote",
        "OPTIONS": {
            "CLIENT_CLASS": "django_redis.client.DefaultClient",
        }
    }
}

LOGIN_URL = reverse_lazy("adfsauth:ws-fed-signin")
LOGOUT_URL = reverse_lazy("adfsauth:ws-fed-signout")

AUTHENTICATION_BACKENDS = (
    'django.contrib.auth.backends.ModelBackend',  # this is default
    'guardian.backends.ObjectPermissionBackend',
    'contrib.adfsauth.backends.WSFedBackend'
)

# Define the Queue Settings

BROKER_URL = os.environ.get('BROKER_URL')


# sorl thumbnail settings

THUMBNAIL_REDIS_URL = "redis://127.0.0.1:6379/0"
THUMBNAIL_KVSTORE = "sorl.thumbnail.kvstores.redis_kvstore.KVStore"
THUMBNAIL_DUMMY = True


# Logging

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'class': 'django.utils.log.AdminEmailHandler',
            'include_html': True
        }
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },
    },
}

# Django Site identification
SITE_ID = 4

# WS UM Members
MEMBERS_SERVICE_CONFIG = {
    'debug': False,
    'url': 'https://ws.uminho.pt/ValidationService/ValidationService.svc?WSDL',
    'login': 'e-vote_dev',
    'password': 'ev0t3_d3v'
}

# WS UM SMS Notifications
SMS_SERVICE_CONFIG = {
    'debug': False,
    'url': 'https://ws.uminho.pt/ShortMessageService/SimpleMessageService.svc?WSDL',  # noqa
    'login': 'e-vote_dev',
    'password': 'ev0t3_d3v'
}

# ADFS AUTH (WS-Fed Sign-In Protocol)
ADFS_WSFED_CONFIG = {
    'url': 'https://auth.uminho-dev.local/adfs/ls/',
    'wtrealm': 'urn:uminho:evotum',
    'cert': os.path.join(PROJECT_DIR, '..', 'data', 'certs', 'cert.pem'),  # noqa
    'claim_mapping': {'nome': 'name',
                      'upn': 'email',
                      'fotografia': 'photo',
                      'telemovel': 'primary_phone'},
    "template_fail": 'voters/signin_fail.html',
    "post_response": "wresult",
}
