/* globals jQuery */

/******************************************************************
 * Site Name: eVote
 * Author: SFR
 *
 * Django forms ajax submission
 * Example:
 *   <form data-ajax-submit>
 *****************************************************************/

"use strict";

(function($) {

    $.fn.djangoAjaxForms = function(options)
    {
        var opts = $.extend({
            fieldIdSelector: "#field_id_",
            fieldWrapperSelector: ".pure-field",
            fieldErrorClass: "errorlist",
            errorClass: "error",

            canSubmitFn: null,
            onFailFn: null,
            onFieldErrorFn: null,
            onNonFieldErrorFn: null,
            onRenderErrorFn: null,
            onSubmit: null,
            onSubmitDone: null,
            onBeforeSubmit: null,
            onSubmitSuccess: null
        }, $.fn.djangoAjaxForms.defaults, options);

        function request(url, data)
        {
            return $.ajax(url, {
                data: data,
                method: 'POST',
                contentType: false,
                processData: false,
                dataType: 'json'
            }).fail(function() {
                if ( $.isFunction( opts.onFailFn ) ) {
                    opts.onFailFn();
                }
            });
        }

        function submit($form)
        {
            if ( $.isFunction( opts.onBeforeSubmit ) ) {
                opts.onBeforeSubmit($form);
            }

            var url = $form.attr("action") || window.location.href;
            var data = new FormData($form.get(0));

            $form.find(':input').prop('disabled', true);

            if ( $.isFunction( opts.onSubmit ) ) {
                opts.onSubmit($form);
            }

            return request(url, data)
                .done(function(response) {
                    processFormErrors($form, response.errors_list);

                    if (!$.isEmptyObject(response.errors_list)) {

                        if ( $.isFunction( opts.onFieldErrorFn ) ) {
                            opts.onFieldErrorFn($form);
                        }

                        $form.find(':input').prop('disabled', false);
                    }
                    else {
                        if ( $.isFunction( opts.onSubmitSuccess ) ) {
                            opts.onSubmitSuccess($form);
                        }
                    }
                    if( response.action){
                        processResponse(response.action, response.action_url);
                    }
                })
                .fail(function () {
                    $form.find(':input').prop('disabled', false);
                })
                .always(function() {
                    if ( $.isFunction( opts.onSubmitDone ) ) {
                        opts.onSubmitDone($form);
                    }
                });
        }

        function processFormErrors($form, errors_list)
        {
            var $wrappers = $form.find(opts.fieldWrapperSelector);
            $wrappers.removeClass(opts.errorClass).find("." + opts.fieldErrorClass).remove();

            for (var field in errors_list) {
                var errors = errors_list[field];

                if (isNestedFormsetErrors(errors)) {
                    processFormErrors($form.find("[data-formset-name='"+field+"']"), errors);
                }
                else {
                    if (field.search("__all__") >= 0) {
                        if ( $.isFunction( opts.onNonFieldErrorFn ) ) {
                            opts.onNonFieldErrorFn( errors );
                        }
                    }
                    else {
                        var $field = $form.find(opts.fieldIdSelector + field);

                        $field.addClass(opts.errorClass).append(renderErrorList(errors));
                    }
                }
            }
        }

        function isNestedFormsetErrors(errors) {
            return $.isPlainObject(errors);
        }

        function processResponse(action, value)
        {
            switch (action) {
                case 'refresh':
                    window.location.reload(true);
                    break;
                case 'redirect':
                    window.location.href = value;
                    break;
                default:
                    return;
            }
        }

        function renderErrorList(errorsList)
        {
            var $elem = $("<ul>").addClass(opts.fieldErrorClass);

            for (var field in errorsList) {
                $elem.append($("<li>").text(errorsList[field]));
            }

            if ( $.isFunction( opts.onRenderErrorFn ) ) {
                $elem = opts.onRenderErrorFn( $elem, errorsList );
            }

            return $elem;
        }

        return this.each(function()
        {
            var $form = $(this),
                canSubmit = true;

            $form.on('submit', function(e){
                e.preventDefault();

                if ( $.isFunction( opts.canSubmitFn ) ) {
                    canSubmit = opts.canSubmitFn($form);
                }

                if ($form.length > 0 && canSubmit) {
                    submit( $form );
                }
            });
        });
    };

    $.fn.djangoAjaxForms.defaults = {};

})(jQuery);
