from django.db.models import Q


class SearchableRegister(object):

    def __init__(self, model, title, content):
        self.model = model
        self.title = title
        self.content = content

    def search(self, search_terms):
        results = []

        title_lookup = self.title + "__icontains"

        content_lookup = self.content + "__icontains"

        q = Q()
        for term in search_terms:
            title_arg = {title_lookup: term, }
            content_arg = {content_lookup: term, }

            q &= Q(**title_arg) | Q(**content_arg)

        qs = self.model._default_manager.filter(q)

        for result in qs:
            results.append({
                self.title: getattr(result, self.title).encode('utf-8'),
                self.content: getattr(result, self.content).encode('utf-8'),
                'url': result.get_absolute_url()
            })

        return results


search_register = []


def searchable(title, content):

    def wrapped(klass):
        search_register.append(SearchableRegister(klass, title, content))
        return klass

    return wrapped
