from __future__ import unicode_literals

import csv
from csvvalidator import CSVValidator

from django.utils.translation import ugettext_lazy as _


class BaseImporter(object):
    """ """
    DELIMITER = b';'

    error_messages = {
        'invalid_header': _("Invalid header"),
        'invalid_record_length': _("Invalid record length"),
    }

    def __init__(self, delimiter=None):
        """ """
        if delimiter:
            self.DELIMITER = delimiter

    def run(self):
        raise NotImplementedError()

    def validate(self, document, limit=0, verbose_errors=False):
        """ """
        data = self.get_csv_data(document)
        result = self.get_validator().validate(data, limit=limit)
        if verbose_errors:
            return self.get_verbose_errors(result, limit)
        return result

    def get_validator(self):
        """ """
        validator = CSVValidator(self.field_names)
        validator.add_header_check(
            message=self.error_messages['invalid_header'])
        validator.add_record_length_check(
            message=self.error_messages['invalid_record_length'])
        return validator

    def get_verbose_errors(self, errors, limit):
        messages = [
            _("(row {}) {}".format(e['row'], e['message'].encode('utf-8')))
            for e in errors
        ]
        if limit and limit <= len(messages):
            messages.append("...")
        return messages

    def get_csv_data(self, document, has_dict=False):
        if has_dict:
            return csv.DictReader(document, delimiter=self.DELIMITER)
        return csv.reader(document, delimiter=self.DELIMITER)
