from smtplib import SMTPException
from django.conf import settings
from django.core.mail import get_connection
from celery.utils.log import get_task_logger

from evote.celery import app

from .utils import deserialize_email

logger = get_task_logger(__name__)


@app.task(**settings.CELERY_EMAIL_TASK_CONFIG)
def send(emails, *args, **kwargs):
    connection = get_connection(backend=settings.CELERY_EMAIL_BACKEND)
    connection.open()
    sent = 0
    emails = [deserialize_email(email) for email in emails]

    for email in emails:
        try:
            email_sent = connection.send_messages([email])
            if email_sent is not None:
                sent += 1
            logger.debug("Email sent to %r.", email.to)
        except SMTPException:
            logger.debug("Failed sending email to %r.", email.to)

    connection.close()
    return sent
