from django.db import models
from guardian.shortcuts import assign_perm

from .mailings import MessageMail, MessageMailCopy


class MessageManager(models.Manager):

    def inbox(self, user, obj):
        if obj:
            return self.filter(
                recipients=user, folder=self.model.Folder.RECIEVED,
                object_id=obj.pk)
        return self.filter(recipients=user, folder=self.model.Folder.RECIEVED)

    def sentbox(self, user, obj):
        if obj:
            return self.filter(
                sender=user, folder=self.model.Folder.SENT,
                object_id=obj.pk)
        return self.filter(sender=user, folder=self.model.Folder.SENT)

    def archivebox(self, user, obj):
        if obj:
            return self.filter(
                recipients=user, folder=self.model.Folder.ARCHIVED,
                object_id=obj.pk)
        return self.filter(recipients=user, folder=self.model.Folder.ARCHIVED)

    def send(self, instance, name='Unknown'):
        """
        Sends messages to recipients
        Returns number of messages sent
        """
        sent = 0
        for recipient in instance.recipients.all():
            obj = self.model.objects.create(
                subject=instance.subject,
                body=instance.body,
                sender=instance.sender,
                anonymous_email=instance.anonymous_email,
                parent=instance.parent,
                folder=self.model.Folder.RECIEVED,
                state=self.model.State.NEW,
                content_object=instance.content_object
            )
            obj.recipients.add(recipient)
            assign_perm("view_message", recipient, obj)
            context = {
                'subject': obj.subject,
                'message': obj.body
            }
            if obj.sender:
                context.update({
                    'name': obj.sender.name,
                    'from': obj.sender.email,
                })
            else:
                context.update({
                    'name': name,
                    'from': obj.anonymous_email,
                })
            MessageMail(context).send([(recipient.name, recipient.email)])
            sent += 1
        return sent

    def notify_anonymous_sender(self, instance, name='Unknown'):
        sent = 0
        if instance.anonymous_email:
            email = instance.anonymous_email
            context = {
                'subject': instance.subject,
                'message': instance.body
            }
            MessageMailCopy(context).send([(name, email)])
            sent += 1
        return sent
