from django.shortcuts import get_object_or_404
from django.conf import settings

from .forms import (MessageAnonymousForm, MessageAuthenticatedForm,
                    MessageAuthenticatedBaseForm)
from .models import Message


class MessageBaseMixin(object):
    """ """
    claim = False
    response = False

    def get_template_names(self):
        base_dir = getattr(settings, "EVOTEMESSAGES_TEMPLATE_BASE_DIR")
        return [base_dir + self.template]


class MessageFormBaseMixin(object):
    """ """

    def get_form_class(self):
        if self.claim and self.request.user.is_authenticated() or\
                self.response:
            return MessageAuthenticatedBaseForm
        elif self.request.user.is_authenticated():
            return MessageAuthenticatedForm
        return MessageAnonymousForm

    def get_form_kwargs(self):
        """ """
        kwargs = super(MessageFormBaseMixin, self).get_form_kwargs()
        if self.request.user.is_authenticated():
            kwargs.update({
                'user': self.request.user
            })
        return kwargs


class MessageViewMixin(MessageBaseMixin, MessageFormBaseMixin):
    """ """

    def get_initial(self):
        initial = super(MessageViewMixin, self).get_initial()
        user = self.request.user
        if 'msg_slug' in self.kwargs:
            parent = get_object_or_404(Message, slug=self.kwargs['msg_slug'])
            initial.update({
                'subject': 'Re: ' + parent.subject
            })
        if user.is_authenticated():
            initial.update({
                'name': user.name,
                'email': user.get_email()
            })
        return initial
