from django.test import TestCase

from evotemessages.models import Message
from evotemessages.managers import MessageManager
from evoteusers.tests.utils import UserTestUtils


class MessageManagerTest(UserTestUtils, TestCase):

    def setUp(self):
        self.user = self.create_user()
        self.message = Message(
            subject='Unit test message',
            body='Unit message',
        )

    def test_send(self):
        self.message.sender = self.user
        sender_two = self.create_user()
        self.message.save()
        self.message.recipients = [self.message.sender, sender_two]
        result = Message.objects.send(self.message)
        self.assertEqual(result, 2)

    def test_send_as_anonymous(self):
        self.message.anonymous_email = 'dev@eurotux.com'
        sender_two = self.create_user()
        self.message.save()
        self.message.recipients = [sender_two]
        result = Message.objects.send(self.message)
        self.assertEqual(result, 1)

    def test_inbox_no_obj(self):
        self.test_send()
        result = Message.objects.inbox(self.user, None)
        expected = Message.objects.filter(
            recipients=self.user, folder=Message.Folder.RECIEVED)
        self.assertQuerysetEqual(result, map(repr, expected))

    def test_sentbox_no_obj(self):
        self.test_send()
        result = Message.objects.sentbox(self.user, None)
        expected = Message.objects.filter(
            sender=self.user, folder=Message.Folder.SENT)
        self.assertQuerysetEqual(result, map(repr, expected))

    def test_archivebox_no_obj(self):
        self.message.folder = Message.Folder.ARCHIVED
        result = Message.objects.archivebox(self.user, None)
        expected = Message.objects.filter(
            recipients=self.user, folder=Message.Folder.ARCHIVED)
        self.assertQuerysetEqual(result, map(repr, expected))

    def test_notify_anonymous_sender(self):
        self.message.anonymous_email = 'dev@eurotux.com'
        result = MessageManager().notify_anonymous_sender(self.message)
        self.assertEqual(result, 1)

    def test_notify_anonymous_sender_nok(self):
        self.message.anonymous_email = None
        result = MessageManager().notify_anonymous_sender(self.message)
        self.assertEqual(result, 0)
