from django.test import TestCase
from django.db import IntegrityError

from evoteusers.models import User


class UserManagerTestCase(TestCase):
    """ """

    def test_create_user(self):
        email = 'dev@eurotux.com'
        user = User.objects.create_user(email)
        self.assertEqual(user.email, email)
        self.assertFalse(user.is_staff)
        self.assertFalse(user.has_usable_password())

    def test_create_superuser(self):
        email = 'dev@eurotux.com'
        user = User.objects.create_superuser(email, password='password')
        self.assertEqual(user.email, email)
        self.assertTrue(user.is_staff)
        self.assertTrue(user.has_usable_password())

    def test_empty_email(self):
        with self.assertRaises(ValueError):
            User.objects.create_user(email='')

    def test_superuser_is_staff_false(self):
        with self.assertRaisesMessage(
                ValueError, 'Superuser must have is_staff=True.'):
            User.objects.create_superuser(
                'dev@eurotux.com', password='password', is_staff=False)


class UserTestCase(TestCase):
    """ """

    def test_unique_email(self):
        email = 'dev@eurotux.com'
        User.objects.create(email=email)
        with self.assertRaises(IntegrityError):
            User.objects.create(email=email)

    def test_full_name(self):
        user = User(name="Sandro Rodrigues")
        self.assertEqual(user.name, user.get_full_name())

    def test_short_name(self):
        user = User(name="Sandro Rodrigues")
        self.assertEqual(user.name, user.get_short_name())

    def test_notice_email_as_default(self):
        user = User(notice_email="dev@eurotux.com")
        self.assertEqual(user.get_email(), user.notice_email)

    def test_notice_email_fallback_to_email(self):
        user = User(email="dev@eurotux.com", notice_email="")
        self.assertEqual(user.get_email(), user.email)

    def test_notice_phone_as_default(self):
        user = User(notice_phone="00351911111111",
                    primary_phone="00351933333333")
        self.assertEqual(user.get_phone(), user.notice_phone)

    def test_notice_phone_fallback_to_primary_phone(self):
        user = User(notice_phone="", primary_phone="00351933333333")
        self.assertEqual(user.get_phone(), user.primary_phone)
