from __future__ import unicode_literals

from django import forms
from django.utils.translation import ugettext_lazy as _

from evoteusers.forms import EvoteAuthenticationForm

from .models import Page, SecretEntry
from .templatetags.admin_tags import is_private_key
from evotecore.widgets import TinymceTextarea


class AdminAuthenticationForm(EvoteAuthenticationForm):
    """Admin user must have is_staff=True"""

    def confirm_login_allowed(self, user, cleaned_data=None):
        super(AdminAuthenticationForm, self).confirm_login_allowed(user)
        if not user.is_staff:
            raise forms.ValidationError(
                self.error_messages['invalid_login'],
                code='invalid_login',
            )


class PageForm(forms.ModelForm):
    """ """

    class Meta:
        model = Page
        fields = ['title_pt', 'title_en', 'body_pt', 'body_en']
        widgets = {
            'body_pt': TinymceTextarea,
            'body_en': TinymceTextarea
        }


class SecretEntryForm(forms.ModelForm):
    """
    The form for a single certificate entry
    """
    document = forms.FileField(required=False)
    password = forms.CharField(
        label="password",
        widget=forms.PasswordInput(
            attrs={
                'placeholder': _(u'Insert the private key password')
            }
        ),
        required=False
    )

    class Meta:
        model = SecretEntry
        fields = ('identifier', 'body', 'password')

    def __init__(self, *args, **kwargs):
        self.request = kwargs.pop('request', None)
        super(SecretEntryForm, self).__init__(*args, **kwargs)
        # Making identifier disabled
        self.fields['identifier'].disabled = True

    def clean_password(self):
        password = self.cleaned_data['password']
        identifier = self.cleaned_data['identifier']
        document = self.files.get(self.prefix + '-document', None)
        # Only validate this field if we are dealing with a private key
        if is_private_key(identifier) and document:

            # PASSWORD VALIDATION MUST OCCUR HERE

            if not password:
                raise forms.ValidationError(_("Invalid private key password."))
                self.add_error('password', _("Invalid private key password"))

            return password

    def clean_body(self):

        body = self.cleaned_data.get('body', None)
        document = self.files.get(self.prefix + '-document', None)

        if document is not None:
            body = document.read()
            self.instance.save()

        return body


SecretEntryFormset = forms.modelformset_factory(
    SecretEntry,
    extra=0,
    form=SecretEntryForm,
    min_num=(
        len(
            SecretEntry.Identifier.choices
        )
    ),
    max_num=(
        len(
            SecretEntry.Identifier.choices
        )
    )
)
