from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _
from django.utils.encoding import python_2_unicode_compatible
from django.conf import settings
from django.urls import reverse
from django.db import models

from autoslug import AutoSlugField

from django_extensions.db.models import TimeStampedModel

from evotecore.decorators import searchable


@python_2_unicode_compatible
class SecretEntry(TimeStampedModel):
    """ """
    class Identifier:

        VOTING_CERT = 0
        VOTING_PVT_KEY = 1
        VALIDATOR_CERT = 2
        VALIDATOR_PVT_KEY = 3
        COUNTER_CERT = 4
        COUNTER_PVT_KEY = 5
        ROOT_CERT = 6
        ROOT_PVT_KEY = 7
        MANAGEMENT_CERT = 8
        MANAGEMENT_PVT_KEY = 9

        private_keys = (
            (VOTING_PVT_KEY, _("Voting Private key")),
            (VALIDATOR_PVT_KEY, _("Validator Private key")),
            (COUNTER_PVT_KEY, _("Counter Private key")),
            (ROOT_PVT_KEY, _("Root Private key")),
            (MANAGEMENT_PVT_KEY, _("Management Private key"))
        )

        certificates = (
            (VOTING_CERT, _("Voting Certificate")),
            (VALIDATOR_CERT, _("Validator Certificate")),
            (COUNTER_CERT, _("Counter Certificate")),
            (ROOT_CERT, _("Root Certificate")),
            (MANAGEMENT_CERT, _("Management Certificate")),
        )

        choices = tuple(
            val for pair in zip(certificates, private_keys) for val in pair
        )

    user = models.ForeignKey(
        settings.AUTH_USER_MODEL, related_name='+', editable=False)
    identifier = models.PositiveSmallIntegerField(
        _("identifier"), choices=Identifier.choices, unique=False)

    body = models.TextField(
        _("body"),
        blank=True,
        null=True
    )

    class Meta:
        verbose_name = _("Secret entry")
        verbose_name_plural = _("Secret entries")
        ordering = ['identifier']

    def __str__(self):
        return self.get_identifier_display()

    @property
    def is_valid(self):
        # print "SecretEntryInstance"
        # print self.pk
        # print "CERT DATA"
        # print self.body
        return self.body is not None and self.body.strip() != ""


@searchable(title='title', content='body')
@python_2_unicode_compatible
class Page(TimeStampedModel):
    """
    The class responsible for modeling the Page representation
    """
    title = models.CharField(_("title"), max_length=128)
    slug = AutoSlugField(
        populate_from='title_en',
        unique=True,
        editable=False
    )
    body = models.TextField(_("body"))
    created_by = models.ForeignKey(
        settings.AUTH_USER_MODEL,
        related_name='+',
        editable=False,
        verbose_name=_("User"),
        on_delete=models.CASCADE
    )

    class Meta:
        verbose_name = _("Page")
        verbose_name_plural = _("Pages")

    def __str__(self):
        return self.title

    def get_absolute_url(self):
        return reverse(
            'voters:page-detail', kwargs={'slug': self.slug}
        )
