from __future__ import unicode_literals

from dhondt import Dhondt


class Vote(object):
    """ """
    _weight = 1
    total = 0
    total_weight = 0

    def __init__(self, weight, total):
        """ """
        self._weight = weight
        self.total = total
        self.total_weight = weight * total


class ListVote(object):
    """ """
    votes = []

    def __init__(self, weights, votes):
        """ """
        self.votes = self._set_votes(weights, votes)

    def _set_votes(self, weights, data):
        """ """
        votes = []
        for weight_id, vote in data.items():
            weight = weights.get(weight_id, None)
            if weight:
                votes.append(Vote(weight, vote))
            else:
                raise ValueError("Weight '{}' don't exists".format(weight_id))
        return votes

    @property
    def total(self):
        """ """
        total = 0
        for vote in self.votes:
            total += vote.total
        return total

    @property
    def total_weight(self):
        """ """
        total = 0
        for vote in self.votes:
            total += vote.total_weight
        return total


class VoteResult(object):

    def __init__(self, cid, total, perc, seats=0):
        """ """
        self.cid = cid
        self.total = total
        self.perc = perc
        self.seats = seats

    def __repr__(self):
        return "{0}: {1}/{2} ({3:.2f})".format(
            self.cid, self.total, self.seats, self.perc)


class VoteCountingBase(list):
    """ """

    candidates = dict()
    votes_status = None
    blank_votes = None
    _weights = None
    _data = None
    invalid_votes = 0
    total_votes = 0

    def __init__(self, weights, data):
        """ """
        self._data = data
        self._weights = weights
        self.total_votes = data['total_votes']
        self.invalid_votes = data['invalid_votes']
        self.votes_status = data['votes_status']
        self.candidates = self.set_candidates(data['candidates'])
        self.blank_votes = self.set_blank_votes(data['blank_votes'])

    def set_candidates(self, data):
        """ """
        candidates = {}
        for cid, results in data.items():
            candidates[cid] = ListVote(self._weights, results)
        return candidates

    def set_blank_votes(self, data):
        """ """
        return ListVote(self._weights, data)

    def perc(self, value, total):
        return float(value) / float(total) * 100

    @property
    def total(self):
        """ """
        total = self.blank_votes.total
        for result in self.candidates.values():
            total += result.total
        return total

    @property
    def total_weight(self):
        """ """
        total = self.blank_votes.total_weight
        for result in self.candidates.values():
            total += result.total_weight
        return total

    @property
    def data(self):
        """ """
        return [r.__dict__ for r in self]

    def count(self):
        """ """
        results = []
        for cid, result in self.candidates.items():
            results.append(VoteResult(
                cid=cid,
                total=result.total_weight,
                perc=self.perc(result.total_weight, self.total_weight)
            ))
        self += sorted(results, key=lambda p: p.total, reverse=True)
        self.append(VoteResult(
            cid='blank',
            total=self.blank_votes.total_weight,
            perc=self.perc(self.blank_votes.total_weight, self.total_weight)
        ))


class DhondtVoteCounting(VoteCountingBase):

    def count(self, total, minper=1):
        """ """
        super(DhondtVoteCounting, self).count()
        dcandi = {r.cid: r.total for r in self[:-1]}
        dhondt = Dhondt(total, minper, dcandi,
                        blankv=self.blank_votes.total_weight, bmp=True)
        for result in self[:-1]:
            result.seats = dhondt.repre[result.cid]


class ProportionalVoteCounting(VoteCountingBase):
    """ """
