from __future__ import unicode_literals

from django.utils import timezone
from django.test import TestCase

from evotevotings.elections.models import ElectoralRoll, Candidate
from .utils import ElectionsTestUtils


class ElectoralRollQuerySetTest(ElectionsTestUtils, TestCase):
    """ """
    def setUp(self):
        self.election = self.create_election()

    def test_get_published_with_published_rolls(self):
        """ """
        electoral_roll = self.create_electoral_roll(
            election=self.election, published_on=timezone.now())
        published = ElectoralRoll.objects.get_published(self.election)
        self.assertIsNotNone(published)
        self.assertEqual(electoral_roll, published)

    def test_get_published_with_unpublished_rolls(self):
        """ """
        self.create_electoral_roll(election=self.election)
        published = ElectoralRoll.objects.get_published(self.election)
        self.assertIsNone(published)

    def test_get_published_return_most_recent_created(self):
        """ """
        electoral_rolls = self.create_electoral_rolls(
            2, election=self.election, published_on=timezone.now())
        published = ElectoralRoll.objects.get_published(self.election)
        self.assertEqual(electoral_rolls[-1], published)

    def test_get_to_publish_with_unpublished_rolls(self):
        """ """
        electoral_rolls = self.create_electoral_rolls(
            2, election=self.election, imported=True)
        # must return the newest unpublished electoral roll
        to_publish = ElectoralRoll.objects.get_to_publish(self.election)
        self.assertEqual(electoral_rolls[-1], to_publish)

    def test_get_to_publish_with_most_recent_roll_published(self):
        """ """
        self.create_electoral_roll(election=self.election)
        self.create_electoral_roll(
            election=self.election, published_on=timezone.now())
        # only can publish if there are electoral rolls unpublished after
        # a published one
        to_publish = ElectoralRoll.objects.get_to_publish(self.election)
        self.assertIsNone(to_publish)


class CandidateManagerTestCase(ElectionsTestUtils, TestCase):
    """ """

    def setUp(self):
        self.election = self.create_election()

    def test_bulk_import(self):
        """ """
        data = [{
            'personnel_number': '123',
            'designation': 'candidate 1'
        }, {
            'personnel_number': '124',
            'designation': 'candidate 2'
        }]
        imported = Candidate.objects.bulk_import(self.election, data)
        found = Candidate.objects.filter(write_in=True, election=self.election)
        self.assertQuerysetEqual(found, map(repr, imported))

    def test_bulk_import_with_existing_candidate_non_write_in(self):
        """ """
        self.create_candidate(election=self.election)
        data = [{
            'personnel_number': '123',
            'designation': 'candidate 1'
        }, {
            'personnel_number': '124',
            'designation': 'candidate 2'
        }]
        imported = Candidate.objects.bulk_import(self.election, data)
        found = Candidate.objects.filter(write_in=True, election=self.election)
        self.assertQuerysetEqual(found, map(repr, imported))

    def test_bulk_import_update_existing_write_in_candidates(self):
        self.create_candidate(
            election=self.election, write_in=True, personnel_number='123',
            designation="Existing candidate")
        data = [{
            'personnel_number': '123',
            'designation': 'Updated candidate'
        }, {
            'personnel_number': '124',
            'designation': 'candidate'
        }]
        candidate = Candidate.objects.get(personnel_number="123")
        self.assertEqual(candidate.designation, "Existing candidate")
        Candidate.objects.bulk_import(self.election, data)
        candidate.refresh_from_db()
        self.assertEqual(candidate.designation, "Updated candidate")
