from __future__ import unicode_literals

from unittest import skip

from django.test import SimpleTestCase

from evotevotings.elections.methods import (Vote, ListVote, VoteCountingBase,
                                            DhondtVoteCounting)


class VoteTest(SimpleTestCase):

    def test_unit_weight(self):
        """ """
        result = Vote(1, 5)
        self.assertEqual(result.total, 5)
        self.assertEqual(result.total_weight, 5)

    def test_weight_not_unit(self):
        result = Vote(2, 5)
        self.assertEqual(result.total, 5)
        self.assertEqual(result.total_weight, 10)


class ListVoteTest(SimpleTestCase):

    def setUp(self):
        """ """
        self.weights = {'cat1': 1, 'cat2': 2}
        self.data = {'cat1': 20, 'cat2': 30}

    def test_init(self):
        """ """
        result = ListVote(self.weights, self.data)
        self.assertEqual(result.total, 50)
        self.assertEqual(result.total_weight, 80)

    def test_init_with_unexistent_weight(self):
        """ """
        self.data['cat'] = 20  # cat is not defined on weight object
        with self.assertRaisesMessage(ValueError, "Weight 'cat' don't exists"):
            ListVote(self.weights, self.data)


class VoteCountingBaseTest(SimpleTestCase):

    def setUp(self):
        """ """
        self.weights = {'cat1': 1, 'cat2': 2}
        self.data = {
            'candidates': {
                'cand1': {'cat1': 20, 'cat2': 30},
                'cand2': {'cat1': 30, 'cat2': 20},
            },
            'blank_votes': {'cat1': 20, 'cat2': 30},
            'votes_status': {'0': 10, '1': 10, '2': 20},
            'total_votes': 150,
            'invalid_votes': 10
        }

    def test_init(self):
        """ """
        counting = VoteCountingBase(self.weights, self.data)
        self.assertEqual(counting.total, 150)
        self.assertEqual(counting.total_weight, 230)
        self.assertEqual(counting.blank_votes.total, 50)
        self.assertEqual(counting.blank_votes.total_weight, 80)
        self.assertEqual(counting.votes_status, self.data['votes_status'])
        self.assertEqual(counting.total_votes, self.data['total_votes'])
        self.assertEqual(counting.invalid_votes, self.data['invalid_votes'])

    def test_count(self):
        counting = VoteCountingBase(self.weights, self.data)
        counting.count()
        self.assertEqual(len(counting), 3)
        self.assertEqual(counting[0].cid, 'cand1')
        self.assertEqual(counting[0].total, 80)
        self.assertEqual(counting[0].perc, 34.78260869565217)
        self.assertEqual(counting[0].seats, 0)


class DhondtVoteCountingTest(SimpleTestCase):

    def setUp(self):
        """ """
        self.weights = {'cat1': 1, 'cat2': 2}
        self.data = {
            'candidates': {
                'cand1': {'cat1': 20, 'cat2': 30},
                'cand2': {'cat1': 30, 'cat2': 20},
            },
            'blank_votes': {'cat1': 20, 'cat2': 30},
            'votes_status': {'0': 10, '1': 10, '2': 20},
            'total_votes': 150,
            'invalid_votes': 10
        }

    @skip("FIX ME")
    def test_count(self):
        counting = DhondtVoteCounting(self.weights, self.data)
        counting.count(100)
        self.assertEqual(counting[0].seats, 65)
        self.assertEqual(counting[1].seats, 35)

    def test_data(self):
        counting = DhondtVoteCounting(self.weights, self.data)
        counting.count(100)
        self.assertEqual(counting.data, [r.__dict__ for r in counting])
