from __future__ import unicode_literals

from unittest import skip
from mock import patch

from django.contrib.auth import get_user_model
from django.test import TestCase, SimpleTestCase
from django.utils import timezone

from evotevotings.elections.models import (Election, ElectoralRoll, Category,
                                           Candidate, ElectionCountQuery)
from evotedocs.models import Document

from .utils import ElectionsTestUtils


class ElectionTest(SimpleTestCase):
    """ """
    def test_str_equal_to_identifier(self):
        instance = Election(identifier="identifier")
        self.assertEqual(str(instance), instance.identifier)


class ElectoralRollTest(SimpleTestCase):
    """ """

    def test_str_equal_to_designation(self):
        document = Document(designation="designation")
        instance = ElectoralRoll(document=document)
        self.assertEqual(str(instance), instance.document.designation)


class CategoryTest(SimpleTestCase):
    """ """

    def test_str_equal_to_designation(self):
        instance = Category(designation="designation")
        self.assertEqual(str(instance), instance.designation)


class CandidateTest(SimpleTestCase):
    """ """

    def test_str_equal_to_designation(self):
        instance = Candidate(designation="designation")
        self.assertEqual(str(instance), instance.designation)


class ElectionCountQueryTest(SimpleTestCase):
    """ """

    def test_str_equal_to_expected_value(self):
        user = get_user_model()(name="test")
        election = Election(identifier="identifier")
        instance = ElectionCountQuery(
            election=election, user=user, total_count=10)
        expected = "{} ({}) - {}".format(
            election.identifier, user.name, instance.total_count)
        self.assertEqual(str(instance), expected)


class ElectionTranstitionTest(ElectionsTestUtils, TestCase):
    """ """
    def setUp(self):
        self.election = self.create_election(
            proposition_end_date=timezone.now() + timezone.timedelta(days=1),
            proposition_begin_date=timezone.now() + timezone.timedelta(days=-1)
        )
        self.create_voter(election=self.election)
        self.create_voter(election=self.election)
        self.create_voter(election=self.election)
        self.create_voter(election=self.election)
        self.create_voter(election=self.election)

        self.create_candidates(4, election=self.election)

    @skip("Need to mock transition methods")
    @patch('evotevotings.elections.models.Election.can_end_proposition')
    def test_end_proposition_transition(self, mock_fn):
        mock_fn.return_value = True
        self.create_electoral_roll(
            election=self.election,
            published_on=timezone.now())
        self.election.state = Election.State.PROVISIONAL_ELECTORAL_ROLL
        self.election.save()
