from __future__ import unicode_literals

from django.core.exceptions import ObjectDoesNotExist
from django.apps import apps

from eVotUM.Cripto import pkiutils, eccblind
from evotevotings.admin.models import SecretEntry
from evotevotings.admin.utils import (get_secret_entry,
                                      get_private_key_password)
import json


def get_election_model():
    return apps.get_model("evoteelections.Election")  # noqa


def get_election_data(election_id=None, user_id=None):
    # Get all necessary data from the database
    try:
        Election = get_election_model()
        election_obj = Election.objects.get(pk=election_id)
        election_cert = election_obj.certificate
        candidates = election_obj.candidates.all().values_list('pk',
                                                               flat=True)
        bulletin = {'election_id': election_id,
                    'candidates': list(candidates)}
        pr_components = election_obj.blindsig_pr_dash_components

        election = {}

        vs_cert = get_secret_entry(
            SecretEntry.Identifier.VALIDATOR_CERT
        )
        votesys_private_key = get_secret_entry(
            SecretEntry.Identifier.VOTING_PVT_KEY
        )
        pvtkey_password = get_private_key_password()

        combo_id = get_user_election(election_id, user_id)

        # Set the blind pr components
        election['pr_dash_components'] = pr_components

        # Set the certificates to be sent
        election['election_cert'] = election_cert
        election['vs_cert'] = vs_cert

        # Set the bulletin information
        election['bulletin'] = json.dumps(bulletin)

        # Sign the needed objects using the system private key
        # Attempt to sign the combo_id {user + election_id}sv
        errorCode, signed_combo_id = pkiutils.signObject(combo_id,
                                                         votesys_private_key,
                                                         pvtkey_password)
        if (errorCode is not None):
            # TODO: Abort and alert (raise exception)
            signed_combo_id = "123456789"

        election['combo_id'] = signed_combo_id

        # Attempt to sign the election_id {election_id}sv
        errorCode, signed_election_id = pkiutils.signObject(
            election_id,
            votesys_private_key,
            pvtkey_password
        )
        if (errorCode is not None):
            # TODO: Abort and alert (raise exception)
            signed_election_id = "987654321"

        election['election_id'] = signed_election_id

        return election

    except ObjectDoesNotExist:
        # TODO: Alert for forged election_id
        return False

    return False


def get_user_election(election_id=None, user_id=None):
    return {'election_id': str(election_id),
            'user_id': str(user_id)}


def initialize_blind_signatures():
    (init_component, pr_component) = eccblind.initSigner()
    return (init_component, pr_component)


def get_extra_election_data(election_id=None, user_id=None):
    # Get all necessary data from the database
    try:
        # Check if Election exists (Exception raised)
        Election = get_election_model()
        Election.objects.get(pk=election_id)

        # Validator Service Certificate
        vs_cert = get_secret_entry(
            SecretEntry.Identifier.VALIDATOR_CERT
        )
        if not vs_cert:
            raise Exception("No Validator Service Certificate found")

        # Voting System Private Key
        votesys_private_key = get_secret_entry(
            SecretEntry.Identifier.VOTING_PVT_KEY
        )
        if not votesys_private_key:
            raise Exception("No Voting System Private Key found")

        # Voting System Private Key password
        pvtkey_password = get_private_key_password()
        if not pvtkey_password:
            raise Exception("No Voting System Pvt Key password found")

        # User/Election combo_id {user + election_id}
        combo_id = get_user_election(election_id, user_id)
        combo_id = json.dumps(combo_id)

        # Sign the needed objects using the system private key
        # Attempt to sign the combo_id {user + election_id}sv
        errorCode, signed_combo_id = pkiutils.signObject(
            combo_id,
            votesys_private_key,
            pvtkey_password
        )

        if errorCode:
            raise Exception("Could not sign election+user ID")

        # Attempt to sign the election_id {election_id}sv
        errorCode, signed_election_id = pkiutils.signObject(
            election_id,
            votesys_private_key,
            pvtkey_password
        )

        if errorCode:
            raise Exception("Could not sign election ID")

        return {
            'combo_id': signed_combo_id,
            'vs_cert': vs_cert,
            'election_id': signed_election_id
        }

    except Exception:
        # TODO: Log
        return False
