/* globals jQuery, django */

/******************************************************************
 * Site Name: eVote
 * Author: Tiago Brito
 *
 * JavaScript: Validate email with DTSI
 *****************************************************************/

"use strict";

(function($) {

    $.fn.VerifyEmailWithDTSI = function(options) {

        var opts = $.extend({}, options);

        return this.each(function()
        {
            var $btn = $(this);
            var $form = $btn.closest('tr');

            $btn.on("click", function() {
                var field = $btn.attr('data-email-verify')
                var target_id = "#" + field;
                var ajax_url = $btn.attr('data-ajax-url');
                var email = $(target_id).val();

                $.ajax({
                    type: "GET",
                    url: ajax_url,
                    data: {
                        'email': email
                    }
                }).done(function(data) {
                    var $email_div = $form.find("#field_" + field);

                    if (data['error']) {
                        $email_div.addClass('error');
                        $email_div.find('.errorlist').remove();
                        $email_div.append("<ul class='errorlist'><li>" + data['error'] + "</li></ul>");
                    } else {
                        $.each(data, function(elem){
                            $form.find("input[name$='" + elem + "']").val(data[elem]);
                        });
                        $.each(data['enable'], function(elem){
                            $form.find("[name$='" + data['enable'][elem] + "']").prop("readonly", false);
                            $form.find("[name$='" + data['enable'][elem] + "']").prop("disabled", false);
                        });
                        $email_div.removeClass('error');
                        $email_div.find('.errorlist').hide();
                        $form.find("[name$=email]").prop("readonly", true);
                        $btn.hide();
                    }
                });
            });
        });
    };

    $.fn.ReloadJSOnFormSet = function(options) {

        var opts = $.extend({}, options);

        return this.each(function()
        {
            var $form = $(this);

            $form.on('formAdded', function(event) {
                var $newForm = $(event.target);
                $newForm.find("[data-email-verify]").VerifyEmailWithDTSI();
            });
        });
    };

    $(document).ready(function () {
        $("[data-email-verify]").VerifyEmailWithDTSI();
        $("[data-js-reload]").ReloadJSOnFormSet();
    });

})(jQuery);
