from __future__ import unicode_literals

from StringIO import StringIO
import json

from django.core.urlresolvers import reverse

from evotevotings.processes.tests.utils import ProcessesTestUtils
from evotevotings.processes.utils import prepopulate_electoralactions
from evoteajaxforms.views import AjaxResponseAction

from. import ManagementTestCase


class ActionValidationAjaxViewTest(ManagementTestCase, ProcessesTestUtils):
    """ """

    fixture = ['actions.json']

    def setUp(self):
        self.login_as_member()
        prepopulate_electoralactions(self.member.electoral_process)
        self.url = reverse("management:action-validate", kwargs={
            "process_pk": self.member.electoral_process.pk,
            "pk": 1
        })

    def test_get(self):
        """ """
        response = self.client.get(self.url)
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(
            response, "management/partials/action_validate.html")

    def test_get_unexistent_action(self):
        """ """
        url = reverse("management:action-validate", kwargs={
            "process_pk": self.member.electoral_process.pk,
            "pk": 100
        })
        response = self.client.get(url)
        self.assertEqual(response.status_code, 404)

    def test_get_unexistent_process(self):
        """ """
        url = reverse("management:action-validate", kwargs={
            "process_pk": 3,
            "pk": 1
        })
        response = self.client.get(url)
        self.assertEqual(response.status_code, 404)

    def test_post(self):
        """ """
        file = StringIO(b"Dummy file")
        data = {'key1': file}
        response = self.client.post(self.url, data=data)
        self.assertEqual(response.status_code, 200)
        response_json = json.loads(response.content)
        self.assertEqual(response_json['action'], AjaxResponseAction.NOTHING)


class ManageActionValidationAjaxViewTest(
        ManagementTestCase, ProcessesTestUtils):
    """ """

    fixture = ['actions.json']

    def setUp(self):
        # prepare a logged in member
        self.login_as_member()
        self.url = reverse("management:manageaction-validate", kwargs={
            "process_pk": self.member.electoral_process.pk,
        })

    def test_get(self):
        """ """
        response = self.client.get(self.url)
        self.assertEqual(response.status_code, 200)
        self.assertTemplateUsed(
            response, "management/partials/action_validate.html")

    def test_get_unexistent_process(self):
        """ """
        url = reverse("management:manageaction-validate", kwargs={
            "process_pk": 3,
        })
        response = self.client.get(url)
        self.assertEqual(response.status_code, 404)

    def test_post(self):
        """ """
        file = StringIO(b"Dummy file")
        data = {"key1": file}
        response = self.client.post(self.url, data=data)
        response_json = json.loads(response.content)
        self.assertEqual(response.status_code, 200)
        self.assertEqual(response_json['action'], AjaxResponseAction.NOTHING)


class ElectoralMemberVerifyViewTest(
        ManagementTestCase, ProcessesTestUtils):
    """ """

    def setUp(self):
        self.login_as_institutional()
        self.process = self.create_electoral_process()
        self.url = reverse("management:electoralmember-verify", kwargs={
            "process_pk": self.process.pk}) +\
            "?email=tfb@eurotux.com"

    def test_get(self):
        """ """
        response = self.client.get(self.url)
        content = json.loads(response.content)
        result = False
        if 'name' in content and content['name'] == 'Dev test':
            result = True
        self.assertEqual(response.status_code, 200)
        self.assertEqual(result, True)

    def test_get_error(self):
        """ """
        url = reverse("management:electoralmember-verify", kwargs={
            "process_pk": self.process.pk}) +\
            "?email=unknown@eurotux.com"
        response = self.client.get(url)
        content = json.loads(response.content)
        result = False
        if 'error' in content:
            result = True
        self.assertEqual(response.status_code, 200)
        self.assertEqual(result, True)
