from __future__ import unicode_literals

from mock import Mock

from evotevotings.management.registers import action_validation

from . import ManagementTestCase


class ActionValidationSessionRegisterTest(ManagementTestCase):

    def setUp(self):
        self.mock = Mock()
        self.mock.session = {}

    def test_prefix_key(self):
        key = action_validation.prefix_key("test")
        self.assertEqual(
            key, "{}_{}".format(action_validation.SESSION_PREFIX, "test"))

    def test_register(self):
        key = action_validation.prefix_key(1)
        action_validation.register(self.mock, 1, "test")
        self.assertIn(key, self.mock.session)
        self.assertEqual(self.mock.session[key], "test")

    def test_reset(self):
        key = action_validation.prefix_key(1)
        action_validation.register(self.mock, 1, "test")
        action_validation.reset(self.mock, 1)
        self.assertNotIn(key, self.mock.session)

    def test_reset_unexistent_key(self):
        with self.assertRaises(KeyError):
            action_validation.reset(self.mock, 1)

    def test_validate_registered_action(self):
        key = action_validation.prefix_key(1)
        action_validation.register(self.mock, 1, "test")
        is_valid = action_validation.validate(self.mock, 1, "test")
        self.assertTrue(is_valid)
        self.assertNotIn(key, self.mock.session)

    def test_validate_unregistered_action(self):
        is_valid = action_validation.validate(self.mock, 1, "test")
        self.assertFalse(is_valid)
