from __future__ import unicode_literals

from django.views.generic.base import RedirectView
from django.conf.urls import url
from django.conf import settings

from evoteusers.views import EvoteLogoutView

from .views import (ElectoralProcessListView, ElectoralProcessDetailView,
                    ElectoralProcessActionsView, ElectionListView,
                    ElectionDetailConfigsView, ElectionDetailCalendarView,
                    ElectionDetailCategoriesView, ElectionDetailRollsView,
                    ElectionDetailCandidatesView, ElectionDetailBulletinView,
                    ElectionDetailBulletinPreviewView,
                    LoginView, ElectoralProcessFormView,
                    ElectoralProcessMembersView, ElectoralProcessSummaryView,
                    ElectoralProcessConfirmationView,
                    ElectoralProcessElectionsView,
                    ElectoralProcessCommunicationView,
                    ElectoralRollDetailView, ElectoralRollPublishView,
                    PersonalDataView, ElectionManageView,
                    ElectionManageCloseView, ElectionManageScrutinizeView,
                    MessagesRecievedListView, MessagesSentListView,
                    MessagesArchivedListView, MessageNewManageView,
                    MessageManageView, ArchiveMessageManageView,
                    DeleteMessageManageView, MessageResponseManageView,
                    ElectoralProcessMembersEditView, GenerateCertificateView)

from .ajax import (ActionValidationAjaxView, ManageActionValidationAjaxView,
                   ElectoralMemberVerifyView, ElectionCountingsPartialView,
                   ElectionScrutinyStatusView, MessageRecipientsManageAjaxView)

app_name = "management"


urlpatterns = [
    url(
        regex=r'^$',
        view=RedirectView.as_view(url=settings.LOGIN_REDIRECT_URL),
        name="index"
    ),
    url(
        regex=r'^login/$',
        view=LoginView.as_view(),
        name="login"
    ),
    url(
        regex=r'^logout/$',
        view=EvoteLogoutView.as_view(),
        name="logout"
    ),
    url(
        regex=r'^personaldata',
        view=PersonalDataView.as_view(),
        name="personal-data"
    ),
    url(
        regex=r'^electoralprocess/$',
        view=ElectoralProcessListView.as_view(),
        name="electoralprocess-list"
    ),
    url(
        regex=r'^electoralprocess/new/$',
        view=ElectoralProcessFormView.as_view(),
        name="electoralprocess-new"
    ),
    # slug rules are greedy, order of urls is important here
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/$',
        view=ElectoralProcessDetailView.as_view(),
        name="electoralprocess-detail"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/messages/recieved/$',
        view=MessagesRecievedListView.as_view(),
        name="messages-recieved"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/messages/sent/$',
        view=MessagesSentListView.as_view(),
        name="messages-sent"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/messages/archived/$',
        view=MessagesArchivedListView.as_view(),
        name="messages-archived"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/messages/new/$',
        view=MessageNewManageView.as_view(),
        name="message-new"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/messages/recipients/$',
        view=MessageRecipientsManageAjaxView.as_view(),
        name="message-recipients"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/messages/'
              r'(?P<msg_slug>[-\w]+)/view/$',
        view=MessageManageView.as_view(),
        name="message-view"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/messages/'
              r'(?P<pk>\d+)/archive/$',
        view=ArchiveMessageManageView.as_view(),
        name="archive-message"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/messages/'
              r'(?P<pk>\d+)/delete/$',
        view=DeleteMessageManageView.as_view(),
        name="delete-message"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/messages/'
              r'(?P<msg_slug>[-\w]+)/response/$',
        view=MessageResponseManageView.as_view(),
        name="message-response"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/edit/$',
        view=ElectoralProcessFormView.as_view(),
        name="electoralprocess-edit"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/edit/elections/$',
        view=ElectoralProcessElectionsView.as_view(),
        name="electoralprocess-elections"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/members/$',
        view=ElectoralProcessMembersView.as_view(),
        name="electoralprocess-members-view"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/members/edit$',
        view=ElectoralProcessMembersEditView.as_view(),
        name="electoralprocess-members-edit"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/communication/$',
        view=ElectoralProcessCommunicationView.as_view(),
        name="electoralprocess-communication"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/summary/$',
        view=ElectoralProcessSummaryView.as_view(),
        name="electoralprocess-summary"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/generate/$',
        view=GenerateCertificateView.as_view(),
        name="electoralprocess-generate"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/confirmation/$',
        view=ElectoralProcessConfirmationView.as_view(),
        name="electoralprocess-confirmation"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/actions/$',
        view=ElectoralProcessActionsView.as_view(),
        name="electoralprocess-actions"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/$',
        view=ElectionListView.as_view(),
        name="election-list"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/manage/$',
        view=ElectionManageView.as_view(),
        name="election-manage"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/manage/close/$',
        view=ElectionManageCloseView.as_view(),
        name="election-manage-close"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/manage/scrutinize/$',
        view=ElectionManageScrutinizeView.as_view(),
        name="election-manage-scrutinize"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/configs/$',
        view=ElectionDetailConfigsView.as_view(),
        name="election-detail-configs"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/calendar/$',
        view=ElectionDetailCalendarView.as_view(),
        name="election-detail-calendar"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/categories/$',
        view=ElectionDetailCategoriesView.as_view(),
        name="election-detail-categories"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/rolls/$',
        view=ElectionDetailRollsView.as_view(),
        name="election-detail-rolls"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/candidates/$',
        view=ElectionDetailCandidatesView.as_view(),
        name="election-detail-candidates"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/bulletin/$',
        view=ElectionDetailBulletinView.as_view(),
        name="election-detail-bulletin"
    ),
    url(
        regex=r'^electoralprocess/(?P<slug>[-\w]+)/elections/'
              r'(?P<slug_election>[-\w]+)/bulletin/preview$',
        view=ElectionDetailBulletinPreviewView.as_view(),
        name="election-detail-bulletin-preview"
    ),
    url(
        regex=r'^electoralroll/(?P<slug>[-\w]+)/$',
        view=ElectoralRollDetailView.as_view(),
        name="electoralroll-detail"
    ),
    url(
        regex=r'^electoralroll/(?P<slug>[-\w]+)/publish/$',
        view=ElectoralRollPublishView.as_view(),
        name="electoralroll-publish"
    ),
]

# ajax urls
urlpatterns += [
    url(
        regex=r'^(?P<process_pk>\d+)/electoral-action/manage/validate/$',
        view=ManageActionValidationAjaxView.as_view(),
        name="manageaction-validate"
    ),
    url(
        regex=r'^(?P<process_pk>\d+)/electoral-action/validate/(?P<pk>\d+)/$',
        view=ActionValidationAjaxView.as_view(),
        name="action-validate"
    ),
    url(
        regex=r'^members/(?P<process_pk>\d+)/verify/$',
        view=ElectoralMemberVerifyView.as_view(),
        name='electoralmember-verify'
    ),
    url(
        regex=r'^(?P<process_pk>\d+)/election/(?P<pk>\d+)/countings/$',
        view=ElectionCountingsPartialView.as_view(),
        name='election-countings'
    ),
    url(
        regex=r'^(?P<process_pk>\d+)/election/(?P<pk>\d+)/scrutiny-status/$',
        view=ElectionScrutinyStatusView.as_view(),
        name='election-scrutiny-status'
    ),
]
