from django.utils.translation import ugettext_lazy as _
from django.contrib.auth import get_user_model
from django.db.models import Q

from evotemessages.decorators import recipients
from evotemessages.recipients import BaseRecipient

from .models import ElectoralProcess, ElectoralMember


@recipients
class ElectoralCommissionRecipient(BaseRecipient):
    """ """
    prefix = 'electoral_commission'
    model = ElectoralProcess
    label = 'identifier'
    label_prefix = _('Electoral commission of process')

    def get_recipients(self, *args, **kwargs):
        slug = kwargs.get('slug', None)
        if slug:
            return self.get_queryset().filter(slug__in=slug)
        else:
            return self.get_queryset().filter(
                identifier__icontains=kwargs.get('q', ''))

    def get_users(self, name):
        obj = self.get_object(name)
        if obj:
            users = obj.electoral_members.values_list('user_id', flat=True)
            return get_user_model().objects.filter(id__in=users)
        return []

    def check_permission(self, user):
        is_member = getattr(user, 'is_electoral_member', False)
        is_voter = getattr(user, 'is_election_voter', False)
        return is_member or is_voter


@recipients
class ElectoralMemberRecipient(BaseRecipient):
    """ """
    prefix = 'electoral_member'
    model = ElectoralMember
    label_prefix = _('Electoral member')

    def get_recipients(self, *args, **kwargs):
        value = kwargs.get('q', '')
        slug = kwargs.get('slug', None)
        if slug:
            return self.get_queryset().filter(
                Q(user__name__icontains=value) |
                Q(user__email__icontains=value),
                electoral_process__slug__in=slug)
        else:
            return self.get_queryset().filter(
                Q(user__name__icontains=value) |
                Q(user__email__icontains=value))

    def get_users(self, name):
        obj = self.get_object(name)
        if obj:
            return [self.get_object(name).user]
        return []

    def get_recipient_label(self, obj):
        return self.label_prefix + " " + obj.user.name

    def check_permission(self, user):
        if hasattr(user, 'is_electoral_member'):
            return user.is_electoral_member
        return False
