from rest_framework.response import Response
from rest_framework.generics import CreateAPIView
from rest_framework.renderers import JSONRenderer
from .utils import generate_blind_signature
from . import serializers


class ValidateVoteView(CreateAPIView):
    """
    Standard API view
    """
    permission_classes = []
    serializer_class = serializers.ValidateVoteSerializer

    def get_serializer_class(self):
        """
        Define the Serializer class to be interpreted
        by Django Swagger
        """
        return self.serializer_class

    def post(self, request, *args, **kwargs):
        """
        POST method docs
        Returns a JSON object with blind signature
        Return codes (0 < code < 10 for cripto errors):
            0 - No errors found
            1 - Empty data
            2 - Invalid data received
        """
        return_code = 0
        obj_data = {}
        return_data = {}
        serializer = serializers.ValidateVoteSerializer(data=request.data)
        if(serializer.is_valid(raise_exception=False)):
            blind_signature = generate_blind_signature(serializer.data)
            if(blind_signature is None):
                return_code = 2
            else:
                obj_data = blind_signature
        else:
            return_code = 1
        return_data['return_code'] = return_code
        return_data['data'] = obj_data
        return Response(JSONRenderer().render(return_data))
