import django_filters

from evotevotings.processes.models import ElectoralProcess
from evotevotings.voters.forms import PerPageFiltersForm, IndexFiltersForm
from evotevotings.elections.models import Election
from evotecore import widgets


def wrapper_choices(queryset):
    def choices():
        return [(obj.year, obj.year) for obj in queryset]
    return choices


class YearFilter(django_filters.ChoiceFilter):
    """
    Custom filter for the year
    """

    def __init__(self, queryset, *args, **kwargs):
        super(YearFilter, self).__init__(
            choices=wrapper_choices(queryset), *args, **kwargs)

    def filter(self, qs, value):
        if value:
            return qs.filter(publication_date__year=value)
        return qs


class VotingEndYearFilter(django_filters.ChoiceFilter):
    """
    Custom filter for the year
    """

    def __init__(self, queryset, *args, **kwargs):
        super(VotingEndYearFilter, self).__init__(
            choices=wrapper_choices(queryset), *args, **kwargs)

    def filter(self, qs, value):
        if value:
            return qs.filter(voting_end_date__year=value)
        return qs


class ArchiveFilter(django_filters.FilterSet):
    """
    Filter of Archives
    """
    publication_date = YearFilter(
        label='',
        widget=widgets.Select,
        queryset=ElectoralProcess.objects.closed().dates(
            'publication_date', 'year'))

    class Meta:
        model = ElectoralProcess
        form = PerPageFiltersForm
        fields = ['publication_date']


class ElectionHistoryFilter(django_filters.FilterSet):
    """
    Filter of History
    """
    voting_end_date = VotingEndYearFilter(
        label='',
        widget=widgets.Select,
        queryset=Election.objects.all().dates(
            'voting_end_date', 'year'))

    class Meta:
        model = Election
        form = PerPageFiltersForm
        fields = ['voting_end_date']


class IndexFilter(django_filters.FilterSet):
    """
    Filter of index page
    """

    class Meta:
        model = ElectoralProcess
        form = IndexFiltersForm
