from __future__ import unicode_literals

from django.db import models

from evoteusers.models import User
from evotecore.utils import compare_data


class ElectionVoterManager(models.Manager):
    """ """

    def bulk_import(self, election, data):
        """Import voter for determined election. Create associated user if
        necessary to allow the voter login in the system.
        Associate permissions to allow user view the election and associated
        electoral process."""
        voters = []
        voters_to_create = []
        registered_emails = User.objects.values_list("email", flat=True)
        for row in data:
            to_create_user_id = None
            row["category_id"] = election.categories.only("id")\
                .get(slug=row["category"]).pk
            if row["email"] not in registered_emails:
                to_create_user_id = User.objects.create(
                    name=row["name"],
                    email=row["email"],
                    primary_phone=row["phone"]
                ).pk
            else:
                # user already exists in database
                try:
                    voter = self.get(
                        election=election, user__email=row["email"])
                    self.efficient_update(voter, row, [
                        "name",
                        "category_id",
                        "personnel_number"
                    ])
                    voters.append(voter)
                except self.model.DoesNotExist:
                    to_create_user_id = User.objects.only("id")\
                        .get(email=row["email"]).pk
            if to_create_user_id:
                voters_to_create.append(self.model(
                    name=row["name"],
                    user_id=to_create_user_id,
                    election=election,
                    category_id=row["category_id"],
                    personnel_number=row["personnel_number"],
                ))
        voters += self.bulk_create(voters_to_create)
        return voters

    def efficient_update(self, voter, data, keys):
        """Only update if data changed, otherwise do nothing"""
        need_update = not compare_data(voter, data, keys)
        if need_update:
            for key in keys:
                setattr(voter, key, data[key])
            voter.save(update_fields=keys)
