from django.utils.translation import ugettext_lazy as _
from django.db.models import Q

from evotemessages.decorators import recipients
from evotemessages.recipients import BaseRecipient

from .models import ElectionVoter


@recipients
class ElectionVoterRecipient(BaseRecipient):
    """ """
    prefix = 'electoral_voter'
    model = ElectionVoter
    label_prefix = _('Election voters:')

    def get_recipients(self, *args, **kwargs):
        value = kwargs.get('q', '')
        slug = kwargs.get('slug', None)
        if slug:
            return self.get_queryset().filter(
                Q(user__name__icontains=value) |
                Q(user__email__icontains=value),
                election__electoral_process__slug__in=slug)
        else:
            return self.get_queryset().filter(
                Q(user__name__icontains=value) |
                Q(user__email__icontains=value))

    def get_users(self, name):
        obj = self.get_object(name)
        if obj:
            return [obj.user]
        return []

    def get_recipient_label(self, obj):
        return self.label_prefix + " " + obj.user.name

    def check_permission(self, user):
        if hasattr(user, 'is_electoral_member'):
            return user.is_electoral_member
        return False
