from __future__ import unicode_literals

from django.test import TestCase

from evotevotings.elections.tests.utils import ElectionsTestUtils
from evotevotings.voters.models import ElectionVoter

from .utils import VotersTestUtils


class ElectionVoterManagerTestCase(
        VotersTestUtils, ElectionsTestUtils, TestCase):
    """ """

    def setUp(self):
        self.election = self.create_election()

    def test_bulk_import(self):
        """ """
        data = [{
            'personnel_number': 1,
            'name': "test",
            'email': "test@test.com",
            'phone': "+351936245558",
            'category': "one"
        }, {
            'personnel_number': 2,
            'name': "test",
            'email': "test2@test.com",
            'phone': "+351936245558",
            'category': "one"
        }]
        imported = ElectionVoter.objects.bulk_import(self.election, data)
        found = ElectionVoter.objects.filter(election=self.election)
        self.assertQuerysetEqual(found, map(repr, imported))

    def test_bulk_import_update_existing_voters(self):
        """ """
        category = self.create_category(election=self.election)
        voter = self.create_election_voter(
            category=category, election=self.election)
        data = [{
            'personnel_number': voter.personnel_number,
            'name': "test",
            'email': voter.user.email,
            'phone': voter.name,
            'category': voter.category.slug
        }]
        imported = ElectionVoter.objects.bulk_import(self.election, data)
        self.assertEqual(len(imported), 1)
        voter.refresh_from_db()
        self.assertEqual(voter.name, "test")

    def test_bulk_import_voter_from_other_election(self):
        """ """
        category = self.create_category(election=self.election)
        voter = self.create_election_voter(
            category=category, election=self.election)
        category2 = self.create_category()
        data = [{
            'personnel_number': voter.personnel_number,
            'name': "test",
            'email': voter.user.email,
            'phone': voter.name,
            'category': category2.slug
        }]
        imported = ElectionVoter.objects.bulk_import(category2.election, data)
        self.assertEqual(len(imported), 1)
        self.assertEqual(imported[0].election, category2.election)
